/*
 *  Copyright (c) 2005-2008, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 *  WSO2 Inc. licenses this file to you under the Apache License,
 *  Version 2.0 (the "License"); you may not use this file except
 *  in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 *
 */

/**
 * This js file is for mediator property specific UI operations
 */

/*
 * Removes the mediator property given by the id in the editing div
 */
function deletemediatorproperty(id) {

    // editing mediator position in the internal model
    var position = geteditingmediatorposition();

    // mediator retrieved and extracting the properties
    var mediator = getnestedmediator(internalmodel.sequence, position);

    collectdata[mediator.nodeName.substring(mediator.nodeName.indexOf(":") + 1, mediator.nodeName.length)](mediator, true);

    setnodepositions(mediator, position);

    var properties = mediator.getElementsByTagName("property");
    // this is a hack to the wrong behaviour of the IE in getElementsByTagName method
    if (properties.length == 0) {
        properties = mediator.getElementsByTagName("syn:property");
    }

    // iterate through the properties and remove the property named to delete
    for (var i = 0; i < properties.length; i++) {
        if (properties[i].getAttribute("esb_med_pos") == id) {
            mediator.removeChild(properties[i]);
        }
    }

    setnodepositions(mediator, position);

    editmediator(position);
}

/*
 * Modifies the editing div to add a new mediator property
 */
function addmediatorproperty() {

    // editing mediator position in the internal model
    var position = geteditingmediatorposition();

    //    vieweditedmediator();

    // mediator retrieved and adding the property with blank fields
    var mediator = getnestedmediator(internalmodel.sequence, position);

    // node.localName is not supported by the IE
    collectdata[mediator.nodeName.substring(mediator.nodeName.indexOf(":") + 1, mediator.nodeName.length)](mediator, true);

    var property;

    // checking the availabality of the createElementNS method and creating the property element
    if (typeof document.createElementNS != 'undefined') {
        property = document.createElementNS(SYNAPSE_NS, "syn:property");
    } else {
        property = getsynproperty();
    }

    // setting the attribute for a blank property
    property.setAttribute("name", "");
    property.setAttribute("value", "");
    var prefix1 = "";
    if (browsername.indexOf(IE_BROWSER_NAME) != -1) {
        prefix1 = "syn:";
    }
    //    var esb_med_pos = position.toString() + "." + mediator.getElementsByTagName(prefix1 + "property").length;
    //    property.setAttribute("esb_med_pos", esb_med_pos);

    mediator.appendChild(property);

    setnodepositions(mediator, position);

    // reload the editing div with the modified internal model
    editmediator(position);
}

function collectproppertydata(mediator) {
    // var propertytrs = document.getElementsByName("syn-property");
    // the above commented code is not working in IE and the following block is a workaround for that
    var propertytrs = new Array();
    var trs = document.getElementsByTagName("tr");
    for (var i = 0; i < trs.length; i++) {
        if (trs[i].getAttribute("name") == "syn-property") {
            propertytrs[propertytrs.length] = trs[i];
        }
    }

    var namespaces = new Array();
    var existingproperties = mediator.getElementsByTagName("property");
    if (existingproperties.length == 0) {
        existingproperties = mediator.getElementsByTagName("syn:property");
        for (var i = 0; i < existingproperties.length; i++) {
            var attrs = existingproperties[i].attributes;
            var nsarr = new Array();
            for (var k = 0; k < attrs.length; k++) {
                if (attrs[k].name.indexOf("xmlns:") == 0) {
                    nsarr[nsarr.length] = attrs[k];
                }
            }
            namespaces[existingproperties[i].getAttribute("esb_med_pos")] = nsarr;
            mediator.removeChild(existingproperties[i]);
        }
    } else {
        while (existingproperties.length > 0) {
            var attrs = existingproperties[existingproperties.length - 1].attributes;
            var nsarr = new Array();
            for (var k = 0; k < attrs.length; k++) {
                if (attrs[k].name.indexOf("xmlns:") == 0) {
                    nsarr[nsarr.length] = attrs[k];
                }
            }
            namespaces[existingproperties[existingproperties.length - 1].getAttribute("esb_med_pos")] = nsarr;
            mediator.removeChild(existingproperties[existingproperties.length - 1]);
        }
    }

    for (var j = 0; j < propertytrs.length; j++) {

        if (window.ActiveXObject) {
            var name = propertytrs[j].children[0].children[0].value;
            if (name == undefined || name == null || name == "") {
                esbwarning("A property with out a name can't exist." +
                           " There are some properties without a name.", TYPE_INFO);
                return false;
            }
            name = trim(name);
            if (!namevalidate(name)) {
                esbwarning(INVALID_NAME, TYPE_INFO);
                return false;
            }
            var propertystr = "<syn:property xmlns:syn='http://ws.apache.org/ns/synapse' name='"
                + name + "' ";

            var propertytype = propertytrs[j].children[1].children[0].options[
                propertytrs[j].children[1].children[0].selectedIndex].value;
            if (propertytype == "value") {
                propertystr += "value='" + convertAllXmlSpecialChars(propertytrs[j].children[2].children[0].value) + "' ";
            } else if (propertytype == "expression") {
                propertystr += "expression='" + convertAllXmlSpecialChars(propertytrs[j].children[2].children[0].value) + "' ";
            }
            if (namespaces[mediator.getAttribute("esb_med_pos").concat(".").concat(j)] != undefined) {
                var nss = namespaces[mediator.getAttribute("esb_med_pos").concat(".").concat(j)];
                for (var g = 0; g < nss.length; g++) {
                    if (nss[g].name != "xmlns:syn") {
                        propertystr += nss[g].name + "='" + nss[g].value + "' ";
                    }
                }
            }
            mediator.appendChild(createesbelement(propertystr + "/>"));
        } else {
            var name = propertytrs[j].childNodes[0].childNodes[0].value;
            if (name == undefined || name == null || name == "") {
                esbwarning("A property with out a name can't exist." +
                           " There are some properties without a name.", TYPE_INFO);
                return false;
            }
            name = trim(name);
            if (!namevalidate(name)) {
                esbwarning(INVALID_NAME, TYPE_INFO);
                return false;
            }

            var property;
            if (document.createElementNS != "undefined") {
                property = document.createElementNS(SYNAPSE_NS, "syn:property");
            }

            property.setAttribute("name", name);
            var propertytype = propertytrs[j].childNodes[1].childNodes[0].options[
                propertytrs[j].childNodes[1].childNodes[0].selectedIndex].value;
            if (propertytype == "value") {
                property.setAttribute("value", propertytrs[j].childNodes[2].childNodes[0].value);
            } else if (propertytype == "expression") {
                property.setAttribute("expression", propertytrs[j].childNodes[2].childNodes[0].value);
            }
            if (namespaces[mediator.getAttribute("esb_med_pos").concat(".").concat(j)] != undefined) {
                var nss = namespaces[mediator.getAttribute("esb_med_pos").concat(".").concat(j)];
                for (var g = 0; g < nss.length; g++) {
                    property.setAttribute(nss[g].name, nss[g].value);
                }
            }
            mediator.appendChild(property);
        }
    }
}

function getsynproperty() {
    var doc = new ActiveXObject("Microsoft.XMLDOM");
    doc.async = "false";
    doc.loadXML("<syn:property xmlns:syn='http://ws.apache.org/ns/synapse'/>");
    return doc.getElementsByTagName("syn:property")[0];
}

/*
 * Modifies the editing div to add a new mediator feature
 */
function addmediatorfeature() {

    // editing mediator position in the internal model
    var position = geteditingmediatorposition();
    // mediator retrieved and adding the feature with blank fields
    var mediator = getnestedmediator(internalmodel.sequence, position);
    // node.localName is not supported by the IE
    collectdata[mediator.nodeName.substring(mediator.nodeName.indexOf(":") + 1, mediator.nodeName.length)](mediator, true);
    var feature;
    // checking the availabality of the createElementNS method and creating the feature element
    if (typeof document.createElementNS != 'undefined') {
        feature = document.createElementNS(SYNAPSE_NS, "syn:feature");
    } else {
        var doc = new ActiveXObject("Microsoft.XMLDOM");
        doc.async = "false";
        doc.loadXML("<syn:feature xmlns:syn='http://ws.apache.org/ns/synapse'/>");
        feature = doc.getElementsByTagName("syn:feature")[0];
    }
    // setting the attribute for a blank feature
    feature.setAttribute("name", "");
    feature.setAttribute("value", "");
    var prefix1 = "";
    if (browsername.indexOf(IE_BROWSER_NAME) != -1) {
        prefix1 = "syn:";
    }
    //    var esb_med_pos = position.toString() + "." + mediator.getElementsByTagName(prefix1 + "feature").length;
    //    feature.setAttribute("esb_med_pos", esb_med_pos);
    mediator.appendChild(feature);
    setnodepositions(mediator, position);
    // reload the editing div with the modified internal model
    editmediator(position);
}

function collectfeaturedata(mediator) {
    // var features = document.getElementsByName("syn-feature");
    // the above commented code is not working in IE and the following block is a workaround for that
    var features = new Array();
    var trs = document.getElementsByTagName("tr");
    for (var i = 0; i < trs.length; i++) {
        if (trs[i].getAttribute("name") == "syn-feature") {
            features[features.length] = trs[i];
        }
    }
    var existingfeatures = mediator.getElementsByTagName("feature");
    if (existingfeatures.length == 0) {
        existingfeatures = mediator.getElementsByTagName("syn:feature");
        for (var i = 0; i < existingfeatures.length; i++) {
            mediator.removeChild(existingfeatures[i]);
        }
    } else {
        while (existingfeatures.length > 0) {
            mediator.removeChild(existingfeatures[existingfeatures.length - 1]);
        }
    }
    for (var j = 0; j < features.length; j++) {
        if (window.ActiveXObject) {
            var name = features[j].children[0].children[0].value;
            if (name == undefined || name == null || name == "") {
                esbwarning("A property with out a name can't exist." +
                           " There are some properties without a name.", TYPE_INFO);
                return false;
            }
            name = trim(name);
            if (!namevalidate(name)) {
                esbwarning(INVALID_NAME, TYPE_INFO);
                return false;
            }

            var featurestr = "<syn:feature xmlns:syn='http://ws.apache.org/ns/synapse' name='"
                + name + "' ";
            featurestr += "value='" + convertAllXmlSpecialChars(features[j].children[1].children[0].value) + "' ";
            mediator.appendChild(createesbelement(featurestr + "/>"));
        } else {
            var name = features[j].childNodes[0].childNodes[0].value;
            if (name == undefined || name == null || name == "") {
                esbwarning("A property with out a name can't exist." +
                           " There are some properties without a name.", TYPE_INFO);
                return false;
            }
            name = trim(name);
            if (!namevalidate(name)) {
                esbwarning(INVALID_NAME, TYPE_INFO);
                return false;
            }


            var feature;
            if (document.createElementNS != "undefined") {
                feature = document.createElementNS(SYNAPSE_NS, "syn:feature");
            }
            feature.setAttribute("name", name);
            feature.setAttribute("value", features[j].childNodes[1].childNodes[0].value);
            mediator.appendChild(feature);

        }
    }
}

/*
 * Removes the mediator feature given by the id in the editing div
 */
function deletemediatorfeature(id) {

    // editing mediator position in the internal model
    var position = geteditingmediatorposition();
    // mediator retrieved and extracting the features
    var mediator = getnestedmediator(internalmodel.sequence, position);
    collectdata[mediator.nodeName.substring(mediator.nodeName.indexOf(":") + 1, mediator.nodeName.length)](mediator, true);
    setnodepositions(mediator, position);
    var features = mediator.getElementsByTagName("feature");
    // this is a hack to the wrong behaviour of the IE in getElementsByTagName method
    if (features.length == 0) {
        features = mediator.getElementsByTagName("syn:feature");
    }
    // iterate through the features and remove the feature named to delete
    for (var i = 0; i < features.length; i++) {
        if (features[i].getAttribute("esb_med_pos") == id) {
            mediator.removeChild(features[i]);
        }
    }
    setnodepositions(mediator, position);
    editmediator(position);
}
