/*
 *  Copyright (c) 2005-2008, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
 *
 *  WSO2 Inc. licenses this file to you under the Apache License,
 *  Version 2.0 (the "License"); you may not use this file except
 *  in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing,
 *  software distributed under the License is distributed on an
 *  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 *  KIND, either express or implied.  See the License for the
 *  specific language governing permissions and limitations
 *  under the License.
 *
 */

var SERVICE_MANAGEMENT = "__ServiceAdmin"

var xslFilepath  ;
var serverDataSet ;
var proxyServiceDataSet ;
var endPointDataSet ;
var sequenceDataSet ;

var xTicksArrayServerGraph ;
var xTicksArrayProxyServiceGraph ;
var xTicksArrayEndPointGraph ;
var xTicksArraySequenceGraph ;

var showGraphDivHome = false;
var showGraphDivInterval = 0;
var REFRESH_GRAPHS = 70000;
var shouldRefesh = 0;

function draw(xTicks, dataset) {
     var hexColor = MochiKit.Color.Color.fromHexString;
     var options = {
        "IECanvasHTC": "/plotkit/iecanvas.htc",
        "axisLabelColor": hexColor("#666666"),
        "backgroundColor":hexColor("#f5f5f5"),
        "axisLabelFont": "Arial",
        "axisLabelFontSize": 12,
        "axisLabelWidth": 180,
        "colorScheme": PlotKit.Base.palette(hexColor("#a9c5d9")),
        "padding": {left: 2, right: 2, top: 2, bottom: 2},
        "xTicks": xTicks,
        "pieRadius": 0.3,
        "drawYAxis": false
    };
    var layout = new PlotKit.Layout("pie", options);
    layout.addDataset("sqrt", dataset);
    layout.evaluate();
    var canvas = MochiKit.DOM.getElement("graph");
    var plotter = new PlotKit.SweetCanvasRenderer(canvas, layout, options);
    plotter.render();
}
function drawServerGraph() {
    draw(top.xTicksArrayServerGraph.get(), top.serverDataSet.get());
}
function drawProxyServiceGraph() {
    draw(top.xTicksArrayProxyServiceGraph.get(), top.proxyServiceDataSet.get());
}
function drawEndPointGraph() {
    draw(top.xTicksArrayEndPointGraph.get(), top.endPointDataSet.get());
}
function drawSequencesGraph() {
    draw(top.xTicksArraySequenceGraph.get(), top.sequenceDataSet.get());
}
function globalStatisticsSettings() {
    var objDiv = document.getElementById("divStatistics");
    showStatistics();
}
function fillDataForGraph(xTicksArray, dataSetArray, valueStr) {
    var values = valueStr.split(";");
    for (var i = 0; i < values.length - 1; i++) {
        var aValue = values[i].split(",");
        xTicksArray.add(aValue[0]);
        dataSetArray.add(parseFloat(aValue[1]));
    }
}
function loadDataSets() {
    var body_xml = '<ns1:getDataForGraphRequest xmlns:ns1="http://org.apache.synapse/xsd">' +
                   ' </ns1:getDataForGraphRequest>';
    var callURL = serverURL + "/" + SERVICE_MANAGEMENT + "/" + "getDataForGraph";
    send("getDataForGraph", body_xml, "", callURL, "", false, loadDataSetsCallBack);
}
function loadDataSetsCallBack() {
    if (!onError()) {
        return;
    }
    var data = getBody(xhReq.responseXML);
    var browsername = navigator.appName;
    var serverStr ;
    var psStr ;
    var epStr ;
    var seqStr ;
    try {
        if (browsername.indexOf(NETSCAPE_BROWSER_NAME) != -1) {
            serverStr = data.getElementsByTagName("serverData")[0].textContent;
            psStr = data.getElementsByTagName("proxyServiceData")[0].textContent;
            epStr = data.getElementsByTagName("endPointData")[0].textContent;
            seqStr = data.getElementsByTagName("sequenceData")[0].textContent;
        }
        else if (browsername.indexOf(IE_BROWSER_NAME) != -1) {
            serverStr = data.getElementsByTagName("serverData")[0].text;
            psStr = data.getElementsByTagName("proxyServiceData")[0].text;
            epStr = data.getElementsByTagName("endPointData")[0].text;
            seqStr = data.getElementsByTagName("sequenceData")[0].text;
        }
    }
    catch(e)
    {
    }
    if (serverStr != "") {
        serverDataSet = new DataSetArray();
        xTicksArrayServerGraph = new XTicksArray();
        fillDataForGraph(xTicksArrayServerGraph, serverDataSet, serverStr);
    }
    if (psStr != "") {
        proxyServiceDataSet = new DataSetArray();
        xTicksArrayProxyServiceGraph = new XTicksArray();
        fillDataForGraph(xTicksArrayProxyServiceGraph, proxyServiceDataSet, psStr);
    }
    if (epStr != "") {
        endPointDataSet = new DataSetArray();
        xTicksArrayEndPointGraph = new XTicksArray();
        fillDataForGraph(xTicksArrayEndPointGraph, endPointDataSet, epStr);
    }
    if (seqStr != "") {
        sequenceDataSet = new DataSetArray();
        xTicksArraySequenceGraph = new XTicksArray();
        fillDataForGraph(xTicksArraySequenceGraph, sequenceDataSet, seqStr);
    }
    var objDiv = document.getElementById("divStatistics");
    callbackhelper("statistics/statisticshome.xsl", objDiv);
    showOnlyOneMain(objDiv, false);
    var graphObj = document.getElementById('divServerGraph');
    if (serverStr != "") {
        graphObj.src = "extensions/core/html/graph1.html";
    } else {
        graphObj.src = "extensions/core/html/blankgraph1.html";
    }
    var graphObj2 = document.getElementById('divProxyServiceGraph');
    if (psStr != "") {
        graphObj2.src = "extensions/core/html/graph2.html";
    } else {
        graphObj2.src = "extensions/core/html/blankgraph2.html";
    }
    var graphObj3 = document.getElementById('divEndPointsGraph');
    if (epStr != "") {
        graphObj3.src = "extensions/core/html/graph3.html";
    } else {
        graphObj3.src = "extensions/core/html/blankgraph3.html";
    }
    var graphObj4 = document.getElementById('divSequencesGraph');
    if (seqStr != "") {
        graphObj4.src = "extensions/core/html/graph4.html";
    } else {
        graphObj4.src = "extensions/core/html/blankgraph4.html";
    }
    if (showGraphDivInterval == 0) {
        showGraphDivInterval = setInterval('refreshGraphs()', REFRESH_GRAPHS);
    }

}
function showStatistics() {
    shouldRefesh = 0;
    loadDataSets();
    if (!onError()) {
        return;
    }

}

function refreshGraphs() {
    if (document.getElementById("divStatistics").style.display == 'none') {
        clearInterval(showGraphDivInterval);
        showGraphDivInterval = 0;
        // this is to counter if focus to divHome is vanished.
        return false;
    }
    if (shouldRefesh == 0) {
        loadDataSets();
    }

}

function showServersInTree(serverid) {
    var body_xml = '<ns1:getSingleServerStatisticsRequest xmlns:ns1="http://org.apache.synapse/xsd">' +
                   '<serverID>' + serverid + '</serverID>' +
                   ' </ns1:getSingleServerStatisticsRequest>';
    var callURL = serverURL + "/" + SERVICE_MANAGEMENT + "/" + "getSingleServerStatistics";
    send("getSingleServerStatistics", body_xml, "", callURL, "", false, showServerTree);
}
function showStatisticsIntree(name, type) {
    var body_xml = '<ns1:getSingleStatisticsRequest xmlns:ns1="http://org.apache.synapse/xsd">' +
                   '<name>' + name + '</name>' +
                   '<type>' + type + '</type>' +
                   ' </ns1:getSingleStatisticsRequest>';
    var callURL = serverURL + "/" + SERVICE_MANAGEMENT + "/" + "getSingleStatistics";
    send("getSingleStatistics", body_xml, "", callURL, "", false, showTree);
}
function listProxyServices() {
    var body_xml = '<ns1:listProxyServicesRequest xmlns:ns1="http://org.apache.synapse/xsd">' +
                   ' </ns1:listProxyServicesRequest>';
    var callURL = serverURL + "/" + SERVICE_MANAGEMENT + "/" + "listProxyServices";
    send("listProxyServices", body_xml, "", callURL, "", false, listProxyServicesCallback);
}
function listProxyServicesCallback() {
    if (!onError()) {
        return;
    }
    var data = getBody(xhReq.responseXML);
    var objDiv = document.getElementById("divStatistics");
    callbackhelper("statistics/list_ps.xsl", objDiv);
    shouldRefesh = 1;
    showOnlyOneMain(objDiv, false);
}

function listServers() {
    var body_xml = '<ns1:listServersRequest xmlns:ns1="http://org.apache.synapse/xsd">' +
                   ' </ns1:listServersRequest>';
    var callURL = serverURL + "/" + SERVICE_MANAGEMENT + "/" + "listServers";
    send("listServers", body_xml, "", callURL, "", false, listServersCallback);
}
function listServersCallback() {
    if (!onError()) {
        return;
    }
    var data = getBody(xhReq.responseXML);
    var objDiv = document.getElementById("divStatistics");
    callbackhelper("statistics/list_servers.xsl", objDiv);
    shouldRefesh = 1;
    showOnlyOneMain(objDiv, false);
}
function listEndPoint() {
    var body_xml = '<ns1:listEndPointRequest xmlns:ns1="http://org.apache.synapse/xsd">' +
                   ' </ns1:listEndPointRequest>';
    var callURL = serverURL + "/" + SERVICE_MANAGEMENT + "/" + "listEndPoint";
    send("listEndPoint", body_xml, "", callURL, "", false, listEndPointCallback);
}
function listEndPointCallback() {
    if (!onError()) {
        return;
    }
    var data = getBody(xhReq.responseXML);
    var objDiv = document.getElementById("divStatistics");
    callbackhelper("statistics/list_epr.xsl", objDiv);
    shouldRefesh = 1;
    showOnlyOneMain(objDiv, false);
}
function listSequence() {
    var body_xml = '<ns1:listSequenceRequest xmlns:ns1="http://org.apache.synapse/xsd">' +
                   ' </ns1:listSequenceRequest>';
    var callURL = serverURL + "/" + SERVICE_MANAGEMENT + "/" + "listSequence";
    send("listSequence", body_xml, "", callURL, "", false, listSequenceCallback);
}
function listSequenceCallback() {
    if (!onError()) {
        return;
    }
    var data = getBody(xhReq.responseXML);
    var objDiv = document.getElementById("divStatistics");
    callbackhelper("statistics/list_seq.xsl", objDiv);
    shouldRefesh = 1;
    showOnlyOneMain(objDiv, false);
}


function showSingleStatistics(name, type) {
    xslFilepath = "statistics/psstatistics.xsl";
    if (name == "__SynapseService") {
        xslFilepath = "statistics/syapseservicestatistics.xsl"
    }
    var body_xml = '<ns1:getSingleStatisticsRequest xmlns:ns1="http://org.apache.synapse/xsd">' +
                   '<name>' + name + '</name>' +
                   '<type>' + type + '</type>' +
                   ' </ns1:getSingleStatisticsRequest>';
    var callURL = serverURL + "/" + SERVICE_MANAGEMENT + "/" + "getSingleStatistics";
    send("getSingleStatistics", body_xml, "", callURL, "", false, showSingleStatisticsCallback);
}

function showSingleStatisticsCallback() {
    if (!onError()) {
        return;
    }
    var data = getBody(xhReq.responseXML);
    var objDiv = document.getElementById("divStatistics");
    callbackhelper(xslFilepath, objDiv);
    shouldRefesh = 1;
    showOnlyOneMain(objDiv, false);
}
function showServerStatistics(serverid) {
    var body_xml = '<ns1:echoServerIdRequest xmlns:ns1="http://org.apache.synapse/xsd">' +
                   '<serverID>' + serverid + '</serverID>' +
                   ' </ns1:echoServerIdRequest>';
    var callURL = serverURL + "/" + SERVICE_MANAGEMENT + "/" + "echoServerId";
    send("echoServerId", body_xml, "", callURL, "", false, showServerStatisticsCallback);
}
function showServerStatisticsCallback() {
    if (!onError()) {
        return;
    }
    var data = getBody(xhReq.responseXML);
    var objDiv = document.getElementById("divStatistics");
    callbackhelper("statistics/list_service_type.xsl", objDiv);
    shouldRefesh = 1;
    showOnlyOneMain(objDiv, false);
}
function veiwServersStatatistics() {
    var body_xml = '<ns1:getServerStatisticsesRequest xmlns:ns1="http://org.apache.synapse/xsd">' +

                   ' </ns1:getServerStatisticsesRequest>';
    var callURL = serverURL + "/" + SERVICE_MANAGEMENT + "/" + "getServerStatisticses";
    send("getServerStatisticses", body_xml, "", callURL, "", false, veiwServersStatatisticsCallback);
}
function veiwServersStatatisticsCallback() {
    if (!onError()) {
        return;
    }
    var data = getBody(xhReq.responseXML);
    var objDiv = document.getElementById("divStatistics");
    callbackhelper("statistics/serverstatistics.xsl", objDiv);
    shouldRefesh = 1;
    showOnlyOneMain(objDiv, false);
}
function clearAllStatistics() {
    var body_xml = '<ns1:clearAllStatisticsRequest xmlns:ns1="http://org.apache.synapse/xsd">' +
                   ' </ns1:clearAllStatisticsRequest>';
    var callURL = serverURL + "/" + SERVICE_MANAGEMENT + "/" + "clearAllStatistics";
    send("clearAllStatistics", body_xml, "", callURL, "", false, clearAllStatisticsCallback);
}
function clearAllStatisticsCallback() {
    if (!onError()) {
        return;
    }
    var data = getBody(xhReq.responseXML);
    showStatistics() ;
}

function getServiceSumary(txProtocolName, serverID) {

    if (txProtocolName == "ProxyServices") {

        var body_xml = '<ns1:getServerProxyStatisticsRequest xmlns:ns1="http://org.apache.synapse/xsd">' +
                       '<serverID>' + serverID + '</serverID>' +
                       '</ns1:getServerProxyStatisticsRequest>';

        var callURL = serverURL + "/" + SERVICE_MANAGEMENT + "/" + "getServerProxyStatistics";
        send("getServerProxyStatistics", body_xml, "", callURL, "", false, showTreeBranch);
    } else if (txProtocolName == "SynapseService") {

        var body_xml = '<ns1:getServerMessageMediationStatisticsRequest xmlns:ns1="http://org.apache.synapse/xsd">' +
                       '<serverID>' + serverID + '</serverID>' +
                       '</ns1:getServerMessageMediationStatisticsRequest>';

        var callURL = serverURL + "/" + SERVICE_MANAGEMENT + "/" + "getServerMessageMediationStatistics";
        send("getServerMessageMediationStatistics", body_xml, "", callURL, "", false, showTreeBranchForSynapseService);
    }

}
function getSummary(txProtocolName, proxyName) {

    if (txProtocolName == "ProxyServices") {

        var body_xml = '<ns1:getServerProxyStatisticsRecordRequest xmlns:ns1="http://org.apache.synapse/xsd">' +
                       '<proxyName>' + proxyName + '</proxyName>' +
                       '</ns1:getServerProxyStatisticsRecordRequest>';

        var callURL = serverURL + "/" + SERVICE_MANAGEMENT + "/" + "getServerProxyStatistics";
        send("getServerProxyStatistics", body_xml, "", callURL, "", false, showTreeBranch);
    } else if (txProtocolName == "SynapseService") {

        var body_xml = '<ns1:getServerProxyStatisticsRequest xmlns:ns1="http://org.apache.synapse/xsd">' +
                       '<proxyName>' + proxyName + '</proxyName>' +
                       '</ns1:getServerProxyStatisticsRequest>';

        var callURL = serverURL + "/" + SERVICE_MANAGEMENT + "/" + "getServerProxyStatistics";
        send("getServerProxyStatistics", body_xml, "", callURL, "", false, showTreeBranchForSynapseService);
    }

}



