<!--
  ~  Copyright (c) 2005-2008, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
  ~
  ~  WSO2 Inc. licenses this file to you under the Apache License,
  ~  Version 2.0 (the "License"); you may not use this file except
  ~  in compliance with the License.
  ~  You may obtain a copy of the License at
  ~
  ~    http://www.apache.org/licenses/LICENSE-2.0
  ~
  ~  Unless required by applicable law or agreed to in writing,
  ~  software distributed under the License is distributed on an
  ~  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  ~  KIND, either express or implied.  See the License for the
  ~  specific language governing permissions and limitations
  ~  under the License.
  ~
  -->

<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:syn="http://ws.apache.org/ns/synapse">

    <xsl:include href="../commons.xsl"/>

    <xsl:template name="element-header">

        <label class="content-header">
            <xsl:choose>
                <xsl:when test="local-name(.)='in'">
                    <img align="top" src="extensions/core/images/in-mediator.gif"/>
                </xsl:when>
                <xsl:when test="local-name(.)='out'">
                    <img align="top" src="extensions/core/images/out-mediator.gif"/>
                </xsl:when>
                <xsl:when test="local-name(.)='drop'">
                    <img align="top" src="extensions/core/images/drop-mediator.gif"/>
                </xsl:when>
                <xsl:otherwise>
                    <img align="top" src="extensions/core/images/mediator.gif"/>
                </xsl:otherwise>
            </xsl:choose>


            <xsl:call-template name="capitalize-first"/>
            <xsl:text> Mediator</xsl:text>
        </label>

    </xsl:template>

    <xsl:template name="capitalize-first">
        <xsl:value-of select="concat(translate(substring(local-name(.),1,1),
            'abcdefghijklmnopqrstuvwxyz','ABCDEFGHIJKLMNOPQRSTUVWXYZ'),
            substring(local-name(.),2,string-length(local-name(.))))"/>
    </xsl:template>

    <xsl:template name="syn-property-view">

        <tr>
            <td>
                <xsl:value-of select="@name"/>
            </td>
            <xsl:if test="@value">
                <td>Value</td>
                <td>
                    <xsl:value-of select="@value"/>
                </td>
            </xsl:if>
            <xsl:if test="@expression">
                <td>Expression</td>
                <td>
                    <xsl:value-of select="@expression"/>
                </td>
            </xsl:if>
        </tr>

    </xsl:template>

    <xsl:template name="syn-feature-view">

        <tr>
            <td>
                <xsl:value-of select="@name"/>
            </td>
            <xsl:if test="@value">
                <td>
                    <xsl:value-of select="@value"/>
                </td>
            </xsl:if>
        </tr>

    </xsl:template>

    <xsl:template name="syn-resource-view">

        <tr>
            <td>
                <xsl:value-of select="@location"/>
            </td>
            <td>
                <xsl:value-of select="@key"/>
            </td>
        </tr>

    </xsl:template>
    
    <xsl:template name="syn-feature-edit">
        <tr>
            <xsl:attribute name="name">syn-feature</xsl:attribute>
            <xsl:attribute name="id">
                <xsl:value-of select="@name"/>
            </xsl:attribute>
            <td>
                <input type="text" id="feature_name" class="esb-edit small_textbox">
                    <xsl:attribute name="value">
                        <xsl:value-of select="@name"/>
                    </xsl:attribute>
                </input>
            </td>
            <xsl:if test="@value">
                <td>
                    <input type="text" id="feature_value" class="esb-edit small_textbox">
                        <xsl:attribute name="value">
                            <xsl:value-of select="@value"/>
                        </xsl:attribute>
                    </input>
                </td>
            </xsl:if>
            <td>
                <a href="#" id="delete_link">
                    <xsl:attribute name="onclick">javascript: deletemediatorfeature('<xsl:value-of select="@esb_med_pos"/>'); return false;
                    </xsl:attribute>
                    &#160;&#160;&#160;&#160;
                </a>
            </td>
        </tr>
    </xsl:template>

    <xsl:template name="syn-property-edit">
        <tr>
            <xsl:attribute name="name">syn-property</xsl:attribute>
            <xsl:attribute name="id"><xsl:value-of select="@name"/></xsl:attribute>
        <td>
            <input type="text" id="property_name" class="esb-edit small_textbox">
                <xsl:attribute name="value"><xsl:value-of select="@name"/></xsl:attribute>
            </input>
        </td>
        <xsl:if test="@value">
            <td>
                <select class="esb-edit small_textbox">
                    <xsl:attribute name="id"><xsl:value-of select="concat('propertyType',@esb_med_pos)"/></xsl:attribute>
                    <xsl:attribute name="onchange">
                        javascript:showNamespaceButtonForProperties('<xsl:value-of select="@esb_med_pos"/>','propertyType','namespaceCell');;
                    </xsl:attribute>
                    <option value="value" selected="true">Value</option>
                    <option value="expression">Expression</option>
                </select>
            </td>
            <td>
                <input type="text" id="property_value" class="esb-edit small_textbox">
                    <xsl:attribute name="value"><xsl:value-of select="@value"/></xsl:attribute>
                </input>
            </td>
            <td>
               <xsl:attribute name="id"><xsl:value-of select="concat('namespaceCell',@esb_med_pos)"/></xsl:attribute> 
            </td>
        </xsl:if>
        <xsl:if test="@expression">
            <td id="property_value">
                <select class="esb-edit small_textbox">
                    <xsl:attribute name="id"><xsl:value-of select="concat('propertyType',@esb_med_pos)"/></xsl:attribute>
                    <xsl:attribute name="onchange">
                        javascript:showNamespaceButtonForProperties('<xsl:value-of select="@esb_med_pos"/>','propertyType','namespaceCell');;
                    </xsl:attribute>
                    <option value="value">Value</option>
                    <option value="expression" selected="true">Expression</option>
                </select>
            </td>
            <td>
                <input type="text" class="esb-edit small_textbox">
                    <xsl:attribute name="value"><xsl:value-of select="@expression"/></xsl:attribute>
                </input>
            </td>
            <td>
                 <xsl:attribute name="id"><xsl:value-of select="concat('namespaceCell',@esb_med_pos)"/></xsl:attribute>
                 <a title="Namespace Editor" class="ns_editor">
                    <xsl:attribute name="onclick">
                        javascript:showNameSpaceEditor('<xsl:value-of select="@esb_med_pos"/>','','');
                    </xsl:attribute>
                     <xsl:text>&#160;&#160;&#160;&#160;</xsl:text>
                 </a>
            </td>
        </xsl:if>
        <td><a href="#" id="delete_link">
            <xsl:attribute name="onclick">javascript: deletemediatorproperty('<xsl:value-of select="@esb_med_pos"/>'); return false;</xsl:attribute>&#160;&#160;&#160;&#160;</a></td>
        </tr>
    </xsl:template>

    <xsl:template name="add_mediator_control">
        <xsl:param name="head_pos"/>
        <br/>
        <div class='nested-mediator-add'><xsl:attribute name="id">mediator-add<xsl:value-of select="$head_pos"/></xsl:attribute>    
            <img src='extensions/core/images/add_mediator.gif'>
                <xsl:attribute name="onclick">javascript:showaddmediator(event, "<xsl:value-of select="$head_pos"/>");return false;</xsl:attribute>                          
            </img>
            <label class='styled-link'>
                <xsl:attribute name="onclick">javascript:showaddmediator(event, "<xsl:value-of select="$head_pos"/>");return false;</xsl:attribute>
                Add Mediator
            </label>
        </div>
    </xsl:template>

    <xsl:template name="panel_control">
        <xsl:param name="head_pos"/>
        <xsl:if test="local-name(.)!='default' and local-name(.)!='schema'">
        <div class="nested-mediator-actions">
            <xsl:attribute name="id"><xsl:value-of select="concat('nested-mediator-actions', $head_pos)"/></xsl:attribute>
            <ul>
                <xsl:if test="local-name(.)!='in' and local-name(.)!='out' and local-name(.)!='drop'">
                    <li>
                        <a>
                            <xsl:attribute name="title">Edit</xsl:attribute>
                            <xsl:attribute name="id">panel_edit</xsl:attribute>
                            <xsl:attribute name="href">
                                <xsl:value-of select="concat('#mediatordiv', $head_pos)"/>
                            </xsl:attribute>
                            <xsl:attribute name="onclick">javascript:editmediator("<xsl:value-of select="$head_pos"/>"); return false;</xsl:attribute>
                            <img src="extensions/core/images/edit.gif"/>
                        </a>
                    </li>
                </xsl:if>
                <xsl:if test="local-name(.)!='case'">
                    <li><a>
                        <xsl:attribute name="title">Add</xsl:attribute>
                        <xsl:attribute name="id">panel_add</xsl:attribute>
                        <xsl:attribute name="href"><xsl:value-of select="concat('#mediatordiv', $head_pos)"/></xsl:attribute>
                        <xsl:attribute name="onclick">javascript:showaddmediator(event, "<xsl:value-of select="$head_pos"/>"); return false;</xsl:attribute>
                        <img src="extensions/core/images/add.gif"/>
                    </a></li>
                </xsl:if>
            <li><a>
                <xsl:attribute name="title">Delete</xsl:attribute>
                <xsl:attribute name="id">panel_delete</xsl:attribute>
                <xsl:attribute name="href"><xsl:value-of select="concat('#mediatordiv', $head_pos)"/></xsl:attribute>
                <xsl:attribute name="onclick">javascript:deletemediator("<xsl:value-of select="$head_pos"/>"); return false;</xsl:attribute>
                <img src="extensions/core/images/delete.gif"/></a></li>
            <xsl:if test="count(preceding-sibling::*) > 0 and local-name(.)!='case'">
                <li><a>
                    <xsl:attribute name="title">Move Up</xsl:attribute>
                    <xsl:attribute name="id">panel_up</xsl:attribute>
                    <xsl:attribute name="href"><xsl:value-of select="concat('#mediatordiv', $head_pos)"/></xsl:attribute>
                    <xsl:attribute name="onclick">javascript:movemediatorup("<xsl:value-of select="$head_pos"/>"); return false;</xsl:attribute>
                    <img src="extensions/core/images/up.gif"/></a></li>
            </xsl:if>
            <xsl:if test="count(following-sibling::*) > 0 and local-name(.)!='case'">
                <li><a>
                    <xsl:attribute name="title">Move Down</xsl:attribute>
                    <xsl:attribute name="id">panel_down</xsl:attribute>
                    <xsl:attribute name="href"><xsl:value-of select="concat('#mediatordiv', $head_pos)"/></xsl:attribute>
                    <xsl:attribute name="onclick">javascript:movemediatordown("<xsl:value-of select="$head_pos"/>"); return false;</xsl:attribute>
                    <img src="extensions/core/images/down.gif"/></a></li>
            </xsl:if>
            </ul>
        </div>
        </xsl:if>
    </xsl:template>

</xsl:stylesheet>