<!--
  ~  Copyright (c) 2005-2008, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
  ~
  ~  WSO2 Inc. licenses this file to you under the Apache License,
  ~  Version 2.0 (the "License"); you may not use this file except
  ~  in compliance with the License.
  ~  You may obtain a copy of the License at
  ~
  ~    http://www.apache.org/licenses/LICENSE-2.0
  ~
  ~  Unless required by applicable law or agreed to in writing,
  ~  software distributed under the License is distributed on an
  ~  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  ~  KIND, either express or implied.  See the License for the
  ~  specific language governing permissions and limitations
  ~  under the License.
  ~
  -->

<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:syn="http://ws.apache.org/ns/synapse"
                xmlns:spring="http://ws.apache.org/ns/synapse/spring"
                xmlns:json="http://ws.apache.org/ns/synapse/json">

    <xsl:variable name="supports-namespace-axis" select="count(/*/namespace::*) &gt; 0"/>

    <xsl:include href="commons.xsl"/>

    <xsl:template match="syn:endpoint | syn:proxy">
        <xsl:param name="level"/>
        <xsl:call-template name="print-xml-edit">
            <xsl:with-param name="level" select="$level"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="*">
        <xsl:param name="level"/>
        <xsl:choose>
            <xsl:when test="$level">
                <xsl:call-template name="print-xml-edit">
                    <xsl:with-param name="level" select="$level"/>
                </xsl:call-template>
            </xsl:when>
            <xsl:otherwise>
                <xsl:call-template name="element-header"/>

        <!--<p class="mediator-description"><img src="extensions/core/images/computer.gif"/> <xsl:text> </xsl:text><xsl:call-template name="capitalize-first"/> Mediator will mediate the messages going through ESB acording to the following configuration</p><br/>-->
        <!--<p>Configurations for <xsl:call-template name="capitalize-first"/>  Mediator</p>-->
        <!--<br/>-->
        <textarea class="esb-edit" style="width: 90%; height: 200px; margin-top: 5px; font-family: monospace;" id="genericmediatoredit">
            <xsl:call-template name="print-xml-edit">
                <xsl:with-param name="level">0</xsl:with-param>
            </xsl:call-template>
        </textarea>
        <br/><br/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>

    <xsl:template name="print-xml-edit">
        <xsl:param name="level"/>
        <xsl:call-template name="element-start-edit">
            <xsl:with-param name="level" select="$level"/>
        </xsl:call-template>
        <xsl:apply-templates>
            <xsl:with-param name="level" select="$level+1"/>
        </xsl:apply-templates>
        <xsl:call-template name="element-end-edit">
            <xsl:with-param name="level" select="$level"/>
        </xsl:call-template>
    </xsl:template>

    <xsl:template name="element-start-edit">
        <xsl:param name="level"/>
        <xsl:if test="$level>0">
            <xsl:text>
</xsl:text>
        </xsl:if>
        <xsl:call-template name="printindent">
            <xsl:with-param name="level" select="$level"/>
        </xsl:call-template>
        <xsl:text>&lt;</xsl:text>
        <xsl:value-of select="name(.)"/>
        <xsl:apply-templates select="@*"/>
        <xsl:call-template name="namespaces">
            <xsl:with-param name="level" select="$level"/> 
        </xsl:call-template>
        <!--<xsl:if test="$level=0 and not(contains(normalize-space(), 'xmlns:syn'))">-->
        <!--<xsl:if test="$level=0">-->
            <!--<xsl:text> xmlns:syn="http://ws.apache.org/ns/synapse"</xsl:text>-->
        <!--</xsl:if>-->
        <xsl:if test="not(node())">
			<xsl:text>/</xsl:text>
		</xsl:if>
	    <xsl:text>&gt;</xsl:text>
    </xsl:template>

    <xsl:template name="element-end-edit">
        <xsl:param name="level"/>
        <xsl:if test="node()">
            <xsl:text>
</xsl:text>
            <xsl:call-template name="printindent">
                <xsl:with-param name="level" select="$level"/>
            </xsl:call-template>
            <xsl:text>&lt;/</xsl:text>
			<xsl:value-of select="name(.)"/>
			<xsl:text>&gt;</xsl:text>
		</xsl:if>
    </xsl:template>

    <xsl:template match="@*">
        <xsl:if test="local-name(.)!='esb_med_pos'">
            <xsl:call-template name="attribute-edit"/>
        </xsl:if>
    </xsl:template>

    <xsl:template name="attribute-edit">
        <xsl:text> </xsl:text>
        <xsl:value-of select="name(.)"/>
        <xsl:text>="</xsl:text>
        <xsl:value-of select="."/>
        <xsl:text>"</xsl:text>
    </xsl:template>

    <xsl:template name="printindent">
        <xsl:param name="level"/>
        <xsl:if test="$level!=0">
            <xsl:text>   </xsl:text>
            <xsl:call-template name="printindent">
                <xsl:with-param name="level" select="$level - 1"/>
            </xsl:call-template>
        </xsl:if>
    </xsl:template>

    <xsl:template name="namespaces">
        <xsl:param name="level"/>
        <xsl:variable name="current" select="current()"/>

        <!-- Unfortunately Mozilla doesn't support the namespace axis, need to check for that and simulate declarations -->
		<xsl:choose>
			<xsl:when test="$supports-namespace-axis">
				<!--
					When the namespace axis is present (e.g. Internet Explorer), we can simulate
					the namespace declarations by comparing the namespaces in scope on this element
					with those in scope on the parent element.  Any difference must have been the
					result of a namespace declaration.  Note that this doesn't reflect the actual
					source - it will strip out redundant namespace declarations. -->

				<xsl:for-each select="namespace::*[. != 'http://www.w3.org/XML/1998/namespace']">
					<xsl:if test="not($current/parent::*[namespace::*[. = current()]]) or $level=0">
						<!--<span class="markup-namespace">-->
							<xsl:text> xmlns</xsl:text>
							<xsl:if test="name() != ''">:</xsl:if>
							<xsl:value-of select="name()"/>
							<xsl:text>="</xsl:text>
						<!--</span>-->
						<!--<span class="markup-namespace-uri">-->
							<xsl:value-of select="."/>
						<!--</span>-->
						<!--<span class="markup-namespace">-->
							<xsl:text>"</xsl:text>
						<!--</span>-->
					</xsl:if>
				</xsl:for-each>
			</xsl:when>
			<xsl:otherwise>
				<!--
					When the namespace axis isn't supported (e.g. Mozilla), we can simulate
					appropriate declarations from namespace elements.
					This currently doesn't check for namespaces on attributes.
					In the general case we can't reliably detect the use of QNames in content, but
					in the case of schema, we know which content could contain a QName and look
					there too.  This mechanism is rather unpleasant though, since it records
					namespaces where they are used rather than showing where they are declared
					(on some parent element) in the source.  Yukk!  -->

				<xsl:if test="namespace-uri(.) != namespace-uri(parent::*) or $level=0">
					<!--<span class="markup-namespace">-->
						<xsl:text> xmlns</xsl:text>
						<xsl:if test="substring-before(name(),':') != ''">:</xsl:if>
						<xsl:value-of select="substring-before(name(),':')"/>
						<xsl:text>="</xsl:text>
					<!--</span>-->
					<!--<span class="markup-namespace-uri">-->
						<xsl:value-of select="namespace-uri(.)"/>
					<!--</span>-->
					<!--<span class="markup-namespace">-->
						<xsl:text>"</xsl:text>
					<!--</span>-->
				</xsl:if>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

</xsl:stylesheet>
