<!--
  ~  Copyright (c) 2005-2008, WSO2 Inc. (http://www.wso2.org) All Rights Reserved.
  ~
  ~  WSO2 Inc. licenses this file to you under the Apache License,
  ~  Version 2.0 (the "License"); you may not use this file except
  ~  in compliance with the License.
  ~  You may obtain a copy of the License at
  ~
  ~    http://www.apache.org/licenses/LICENSE-2.0
  ~
  ~  Unless required by applicable law or agreed to in writing,
  ~  software distributed under the License is distributed on an
  ~  "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  ~  KIND, either express or implied.  See the License for the
  ~  specific language governing permissions and limitations
  ~  under the License.
  ~
  -->

<xsl:stylesheet version="1.0"
                xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

    <xsl:template match="*">
        <xsl:choose>
            <xsl:when test="count(//return) != 0">
                <table>
                    <tbody>
                        <tr>
                            <td>
                                <table id="static_table_content">
                                    <th>Server Name</th>
                                    <th>Message Flow Direction</th>
                                    <th>Total Request Count</th>
                                    <th>Total Fault Count</th>
                                    <th>Average Response Time</th>
                                    <th>Minimum Response Time</th>
                                    <th>Maximum Response Time</th>
                                    <tbody>
                                        <xsl:call-template name="print-row">
                                            <xsl:with-param name="value">
                                                <xsl:value-of select="count(//return)"/>
                                            </xsl:with-param>
                                            <xsl:with-param name="limit">
                                                <xsl:value-of select="count(//return)"/>
                                            </xsl:with-param>
                                        </xsl:call-template>
                                    </tbody>
                                </table>
                            </td>
                        </tr>
                    </tbody>
                </table>
            </xsl:when>
            <xsl:otherwise>
                <br/>
                <i>
                    <font style='color: brown'>No data available</font>
                </i>
                <br/>
                <br/>
            </xsl:otherwise>
        </xsl:choose>
    </xsl:template>
    <xsl:template name="print-row">
        <xsl:param name="value"/>
        <xsl:param name="limit"/>
        <xsl:if test="$value != 0">
            <xsl:if test="$value mod 2 = 0">
                <tr>
                    <xsl:call-template name="print-statistics">
                        <xsl:with-param name="index" select="($limit +1) - $value"/>
                    </xsl:call-template>
                </tr>
                <xsl:call-template name="print-row">
                    <xsl:with-param name="value" select="$value - 1"/>
                    <xsl:with-param name="limit" select="$limit"/>
                </xsl:call-template>
            </xsl:if>
            <xsl:if test="$value mod 2 = 1">
                <tr bgcolor="#E3E4FA">
                    <xsl:call-template name="print-statistics">
                        <xsl:with-param name="index" select="($limit +1) - $value"/>
                    </xsl:call-template>
                </tr>
                <xsl:call-template name="print-row">
                    <xsl:with-param name="value" select="$value - 1"/>
                    <xsl:with-param name="limit" select="$limit"/>
                </xsl:call-template>
            </xsl:if>
        </xsl:if>
    </xsl:template>
    <xsl:template name="print-statistics">
        <xsl:param name="index"/>
        <td>
            <xsl:element name="a">
                <xsl:attribute name="href">#</xsl:attribute>
                <xsl:attribute name="onClick">javascript:showServerStatistics('<xsl:value-of select="//return[$index]/serverId"/>'); return false;
                </xsl:attribute>
                <xsl:value-of select="//return[$index]/serverId"/>
            </xsl:element>
        </td>
        <td>
        <xsl:if test="//return[$index]/direction=0">
            <xsl:text>IN</xsl:text>
        </xsl:if>
        <xsl:if test="//return[$index]/direction=1">
            <xsl:text>OUT</xsl:text>
        </xsl:if>
        </td>
        <td>
            <xsl:value-of select="//return[$index]/totalCount"/>
        </td>
        <td>
            <xsl:value-of select="//return[$index]/faultCount"/>
        </td>
        <td>
            <xsl:value-of select="format-number(//return[$index]/avgTime,'#.##')"/>
            ms
        </td>
        <td>
            <xsl:choose>
                <xsl:when test="minTime=0">
                    &lt; 1.00 ms
                </xsl:when>
                <xsl:otherwise>
                    <xsl:value-of select="format-number(//return[$index]/minTime,'0.00')"/>
                    ms
                </xsl:otherwise>
            </xsl:choose>
        </td>
        <td>
            <xsl:value-of select="format-number(//return[$index]/maxTime,'0.00')"/>
            ms
        </td>

    </xsl:template>

</xsl:stylesheet>